@@ -104,9 +104,16 @@ wikitext.type_render_map -- A dictionary mapping tiddler.type MIME-
 TYPES to modules with a render() function for turning that content-type
 into HTML.
 
+wsgi_server -- The name of a module that provides a start_server method
+which starts a server to run this TiddlyWeb instance. Used by the twanager
+server command only.
+
 special_bag_detectors -- A list of functions that take an environ and bag
 name and return a tuple of two functions: the first returns the tiddlers
 in that bag, the second returns one tiddler from that bag.
+
+collections.use_memory -- If True Tiddler Collections are kept in
+memory during a single request. Defaults to False to save memory.
 """
 
 try:
@@ -179,8 +186,10 @@ DEFAULT_CONFIG = {
         'css_uri': '',
         'wikitext.default_renderer': 'raw',
         'wikitext.type_render_map': {},
+        'wsgi_server': 'tiddlyweb.web.serve',
         'root_dir': '',
         'special_bag_detectors': [],
+        'collections.use_memory': False,
 }
 
 
